CodeChange

Struct CodeChange 

pub struct CodeChange {
    pub block_access_index: BlockAccessIndex,
    pub new_code: Bytes,
}
This struct is used to track the new codes of accounts in a block.

Fields

block_access_index: BlockAccessIndex

The index of bal that stores this code change.

new_code: Bytes

The new code of the account.

Implementations

Source

impl CodeChange

pub const fn new(block_access_index: BlockAccessIndex, new_code: Bytes) -> Self

Creates a new CodeChange.

pub const fn block_access_index(&self) -> BlockAccessIndex

Returns the bal index.

pub const fn new_code(&self) -> &Bytes

Returns the new code.