Module diff

Module diff 

Module for comparing block access lists. Helpers for finding the first divergence between block access lists.

Structs

AccountDiff
Account-level details for the first differing BAL entry.
AccountFieldDiff
Per-field difference flags for account entries with the same address.
AccountSummary
Compact account summary included in AccountDiff.
BalDiff
Compact summary of the first difference between two block access lists.

Functions

first_bal_divergence
Returns a compact diff describing the first divergence between two BALs.