BlockAccessListValidationError

Enum BlockAccessListValidationError 

pub enum BlockAccessListValidationError {
    DuplicateAccount {
        address: Address,
    },
    AccountsOutOfOrder {
        previous: Address,
        address: Address,
    },
    DuplicateStorageKey {
        address: Address,
        slot: U256,
    },
    StorageKeysOutOfOrder {
        address: Address,
        previous: U256,
        slot: U256,
    },
    EmptyStorageChanges {
        address: Address,
        slot: U256,
    },
    DuplicateBlockAccessIndex {
        address: Address,
        kind: BlockAccessListChangeKind,
        index: BlockAccessIndex,
    },
    ChangeIndicesOutOfOrder {
        address: Address,
        kind: BlockAccessListChangeKind,
        previous: BlockAccessIndex,
        index: BlockAccessIndex,
    },
    BlockAccessIndexOutOfRange {
        address: Address,
        kind: BlockAccessListChangeKind,
        index: BlockAccessIndex,
    },
    BlockAccessIndexExceedsBlock {
        address: Address,
        kind: BlockAccessListChangeKind,
        index: BlockAccessIndex,
        max: BlockAccessIndex,
    },
}
Error returned when a decoded EIP-7928 block access list is invalid.

Variants



DuplicateAccount

The same account occurs more than once.

Fields

address: Address

Duplicated account address.



AccountsOutOfOrder

Account entries are not ordered lexicographically by address.

Fields

previous: Address

Previous account address.

address: Address

Out-of-order account address.



DuplicateStorageKey

The same storage key occurs more than once or in both storage lists.

Fields

address: Address

Account containing the duplicated key.

slot: U256

Duplicated storage key.



StorageKeysOutOfOrder

Storage keys in one of the account’s lists are not in canonical order.

Fields

address: Address

Account containing the out-of-order key.

previous: U256

Previous storage key.

slot: U256

Out-of-order storage key.



EmptyStorageChanges

A storage change entry has no changes.

Fields

address: Address

Account containing the empty entry.

slot: U256

Storage key with no changes.



DuplicateBlockAccessIndex

The same block access index occurs more than once in one change list.

Fields

address: Address

Account containing the change list.

kind: BlockAccessListChangeKind

Kind of change list.

index: BlockAccessIndex

Duplicated block access index.



ChangeIndicesOutOfOrder

A change list is not ordered by block access index.

Fields

address: Address

Account containing the change list.

kind: BlockAccessListChangeKind

Kind of change list.

previous: BlockAccessIndex

Previous block access index.

index: BlockAccessIndex

Out-of-order block access index.



BlockAccessIndexOutOfRange

A block access index does not fit the EIP-7928 uint32 representation.

Fields

address: Address

Account containing the change list.

kind: BlockAccessListChangeKind

Kind of change list.

index: BlockAccessIndex

Invalid block access index.



BlockAccessIndexExceedsBlock

A block access index is greater than the block’s post-execution index.

Fields

address: Address

Account containing the change list.

kind: BlockAccessListChangeKind

Kind of change list.

index: BlockAccessIndex

Invalid block access index.

max: BlockAccessIndex

Post-execution index for the block.