pub struct CodeChange {
pub block_access_index: BlockAccessIndex,
pub new_code: Bytes,
}Expand description
This struct is used to track the new codes of accounts in a block.
Fields
block_access_index: BlockAccessIndexThe index of bal that stores this code change.
new_code: BytesThe new code of the account.
Implementations
Sourceimpl CodeChange
impl CodeChange
Sourcepub const fn new(block_access_index: BlockAccessIndex, new_code: Bytes) -> Self
pub const fn new(block_access_index: BlockAccessIndex, new_code: Bytes) -> Self
Creates a new CodeChange.
Sourcepub const fn block_access_index(&self) -> BlockAccessIndex
pub const fn block_access_index(&self) -> BlockAccessIndex
Returns the bal index.