pub enum BlockAccessListValidationError {
DuplicateAccount {
address: Address,
},
AccountsOutOfOrder {
previous: Address,
address: Address,
},
DuplicateStorageKey {
address: Address,
slot: U256,
},
StorageKeysOutOfOrder {
address: Address,
previous: U256,
slot: U256,
},
EmptyStorageChanges {
address: Address,
slot: U256,
},
DuplicateBlockAccessIndex {
address: Address,
kind: BlockAccessListChangeKind,
index: BlockAccessIndex,
},
ChangeIndicesOutOfOrder {
address: Address,
kind: BlockAccessListChangeKind,
previous: BlockAccessIndex,
index: BlockAccessIndex,
},
BlockAccessIndexOutOfRange {
address: Address,
kind: BlockAccessListChangeKind,
index: BlockAccessIndex,
},
BlockAccessIndexExceedsBlock {
address: Address,
kind: BlockAccessListChangeKind,
index: BlockAccessIndex,
max: BlockAccessIndex,
},
}Expand description
Error returned when a decoded EIP-7928 block access list is invalid.
Variants
DuplicateAccount
The same account occurs more than once.
AccountsOutOfOrder
Account entries are not ordered lexicographically by address.
DuplicateStorageKey
The same storage key occurs more than once or in both storage lists.
StorageKeysOutOfOrder
Storage keys in one of the account’s lists are not in canonical order.
Fields
EmptyStorageChanges
A storage change entry has no changes.
DuplicateBlockAccessIndex
The same block access index occurs more than once in one change list.
Fields
kind: BlockAccessListChangeKindKind of change list.
index: BlockAccessIndexDuplicated block access index.
ChangeIndicesOutOfOrder
A change list is not ordered by block access index.
Fields
kind: BlockAccessListChangeKindKind of change list.
previous: BlockAccessIndexPrevious block access index.
index: BlockAccessIndexOut-of-order block access index.
BlockAccessIndexOutOfRange
A block access index does not fit the EIP-7928 uint32 representation.
Fields
kind: BlockAccessListChangeKindKind of change list.
index: BlockAccessIndexInvalid block access index.
BlockAccessIndexExceedsBlock
A block access index is greater than the block’s post-execution index.
Fields
kind: BlockAccessListChangeKindKind of change list.
index: BlockAccessIndexInvalid block access index.
max: BlockAccessIndexPost-execution index for the block.